@@ -1,6 +1,7 @@
 #!/usr/bin/python3 
 from requests import get
 import XForce.details
+from json import loads
 
 api_url = "https://exchange.xforce.ibmcloud.com/api" 
 
@@ -27,10 +28,6 @@ def industries(term, auth):
 
 def all(term, auth):
     big_list = []
-    big_list.append(eval(threat_activities(term, auth))["rows"])
-    big_list.append(eval(malware_analysis(term, auth))["rows"])
-    big_list.append(eval(threat_groups(term, auth))["rows"])
-    big_list.append(eval(collector(term, auth))["casefiles"])
-    big_list.append(eval(industries(term, auth))["rows"])
+    big_list = loads(threat_activities(term, auth))["rows"] + loads(malware_analysis(term, auth))["rows"] + loads(threat_groups(term, auth))["rows"] + loads(collector(term, auth))["casefiles"] + loads(industries(term, auth))["rows"]
     return big_list
 
